%IMTRANSFORM2 applies transformations to an image
%
%  newImage = imtransform2(origImage,T2) applies the transformation
%  specified by T2 to origImage, producing newImage
%
%  Inputs:
%   1) origImage: Image to apply the transformation to
%   2) T2: Transformation matrix
%  Outputs:
%   1) newImage: Image obtained by applying T2 to origImage
%
%  newImage = origImage*T2 (right multiplication).  Thus the affect of the
%  transformation matrix can be summarized as:
%  [scale   sh    homog
%   sh     scale  homog
%   tran   tran     1  ]


function newImage = imtransform2(origImage,T2)
[is js] = meshgrid(1:size(origImage,2),1:size(origImage,1));
originalImgCoords = [is(:) js(:) ones(numel(origImage),1)];

newImgCoords = originalImgCoords*T2;
newImgCoords(:,1) = newImgCoords(:,1)./newImgCoords(:,3);
newImgCoords(:,2) = newImgCoords(:,2)./newImgCoords(:,3);
newImgCoords = newImgCoords(:,1:2);
newImage = interp2(double(origImage),reshape(newImgCoords(:,1),...
    [size(origImage,1) size(origImage,2)]),reshape(newImgCoords(:,2),...
    [size(origImage,1) size(origImage,2)]));
newImage(isnan(newImage))=0;

